from _stories.context import Context
from _stories.returned import Success

class BeginningOfStory:
    def __init__(self, cls_name: str, name: str) -> None: ...
    def __call__(self, ctx: Context) -> Success: ...
    def set_parent(self, parent_name: str, same_object: bool) -> None: ...

class EndOfStory:
    def __call__(self, ctx: Context) -> Success: ...
