{% if stories %}
<table>
  <thead>
    <tr>
      <th>&#160;</th>
      <th>Context</th>
    </tr>
  </thead>
  <tbody>
    {% for ctx in stories %}
    <tr>
      <td>&#160;</td>
      <td>
        <pre><code>{{ ctx }}</code></pre>
      </td>
    </tr>
    {% endfor %}
  </tbody>
</table>
{% else %}
<p>No story calls were recorded during this request.</p>
{% endif %}
