from enum import Enum
from typing import Optional
from typing import Union

class StoryError: ...
class StoryDefinitionError: ...

class FailureError:
    def __init__(self, reason: Optional[Union[str, Enum]]) -> None: ...
    def __repr__(self) -> str: ...

class FailureProtocolError: ...
class ContextContractError: ...
class MutationError: ...
