# -*- coding: utf-8 -*-
# type: ignore
"""
stories.contrib.debug_toolbars.flask
------------------------------------

This module contains integration with flask-debugtoolbar.

:copyright: (c) 2018-2020 dry-python team.
:license: BSD, see LICENSE for more details.
"""
from _stories.contrib.debug_toolbars.flask.panels import StoriesPanel


__all__ = ["StoriesPanel"]
