# -*- coding: utf-8 -*-
"""
stories.shortcuts
-----------------

This module contains convenient functions to reduce boilerplate code.

:copyright: (c) 2018-2020 dry-python team.
:license: BSD, see LICENSE for more details.
"""
from _stories.shortcuts import contract_in
from _stories.shortcuts import failures_in


__all__ = ["contract_in", "failures_in"]
