# -*- coding: utf-8 -*-
# type: ignore
"""
stories.contrib.pytest
----------------------

This module contains integration with PyTest framework.

:copyright: (c) 2018-2020 dry-python team.
:license: BSD, see LICENSE for more details.
"""
from _stories.contrib.pytest import pytest_runtest_call


__all__ = ["pytest_runtest_call"]
